@@ -16,7 +16,7 @@ use Path::Tiny 'path';
 use Text::Diff ();
 use Try::Tiny qw( try catch finally );
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.25'; # VERSION
 
 sub init {
     my $self = _new( shift, 'expect_no_root_dir' );
@@ -269,10 +269,19 @@ sub clean {
 sub preinstall {
     my $self = _new(shift);
 
-    for ( map { $self->_rel2root($_) } $self->_watch_list ) {
-        my $dest = $self->_rel2dir(".dest/$_");
-        rmtree($dest);
-        mkdir($dest);
+    if (@_) {
+        for (@_) {
+            my $dest = $self->_rel2dir(".dest/$_");
+            rmtree($dest);
+            mkdir($dest);
+        }
+    }
+    else {
+        for ( map { $self->_rel2root($_) } $self->_watch_list ) {
+            my $dest = $self->_rel2dir(".dest/$_");
+            rmtree($dest);
+            mkdir($dest);
+        }
     }
 
     return 0;
@@ -754,7 +763,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -776,11 +785,12 @@ dest COMMAND [OPTIONS]
     dest make NAME [EXT]    # create a named template set (set of 3 files)
     dest expand NAME        # dump a list of the template set (set of 3 files)
     dest list [FILTER]      # list all actions in all watches
+    dest prereqs [FILTER]   # like "list" but include report of prereqs
 
     dest status             # check status of tracked directories
     dest diff [NAME]        # display a diff of any modified actions
     dest clean [NAME]       # reset dest state to match current files/dirs
-    dest preinstall         # set dest state so an update will deploy everything
+    dest preinstall [NAME]  # set dest state so an update will deploy everything
 
     dest deploy NAME [-d]   # deployment of a specific action
     dest verify [NAME]      # verification of tracked actions or specific action
@@ -931,7 +941,7 @@ yet been deployed (marked with a "+"), features that have been deployed in your
 current system state but are missing from the code (marked with a "-"), and
 changes to previously existing files (marked with an "M").
 
-=head2 diff
+=head2 diff [NAME]
 
 This will display a diff delta of the differences of any modified action files.
 You can specify an optional name parameter that refers to a tracking directory,
@@ -941,7 +951,7 @@ action name, or specific sub-action.
     dest diff db/schema
     dest diff db/schema/deploy
 
-=head2 clean
+=head2 clean [NAME]
 
 Let's say that for some reason you have a delta between what C<dest> thinks your
 system is and what your code says it ought to be, and you really believe your
@@ -949,12 +959,12 @@ code is right. You can call C<clean> to tell C<dest> to just assume that what
 the code says is right.
 
 You can optionally provide a specific action or even a step of an action to
-clean. For example:
+C<clean>. For example:
 
     dest clean db/schema
     dest clean db/schema/deploy
 
-=head2 preinstall
+=head2 preinstall [NAME]
 
 Let's say you're setting up a new system or installing the project/application,
 so you start by creating yourself a working directory. At some point, you'll
@@ -971,6 +981,9 @@ Here's an example of what you might want:
     dest preinstall
     dest update
 
+You can optionally provide a specific action or even a step of an action to
+C<preinstall> similar to C<clean>.
+
 =head2 deploy NAME [-d]
 
 This tells C<dest> to deploy a specific action. For example, if you called
